==> nextcloud-16.0.9.tar.bz2: nextcloud/apps/privacy/l10n/fa.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "حریم خصوصی",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "مرکز حفظ حریم خصوصی به شما نشان می دهد که داده های شما در کجا ذخیره شده است و چه کسی می تواند به آن دسترسی پیدا کند ، یا بخاطر اینکه با آنها به اشتراک گذاشته اید یا به دلیل اینکه آنها مدیر هستند",
    "Remove external admin" : "مدیر خارجی را حذف کنید",
    "Add external admin" : "مدیر خارجی را افزودن",
    "Your files are not protected by encryption." : "پرونده های شما توسط رمزگذاری محافظت نمی شوند.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "فایل های خود را با {} linkopen سمت سرور رمزگذاری ↗ {linkclose} رمزگذاری شده است.",
    "This server is protected with full-disk-encryption." : "این سرور با رمزگذاری کامل دیسک محافظت می شود.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "فایل های خود را با {} linkopen سمت سرور رمزگذاری ↗ {linkclose} رمزگذاری شده است. علاوه بر این ، این سرور با رمزگذاری کامل دیسک محافظت می شود.",
    "This server is using full-disk-encryption." : "این سرور از رمزگذاری کامل دیسک استفاده می کند.",
    "Change data location" : "مکان داده را تغییر دهید",
    "Your data is located in: " : "داده شما در:",
    "The admin hasn't selected the location of the server yet." : "مدیر هنوز محل سرور را انتخاب نکرده است.",
    "Please select a country" : "لطفاً یک کشور را انتخاب کنید",
    "You don't have any shares with individual users." : "شما با کاربران جداگانه اشتراکی ندارید.",
    "Somaliland" : "سومالیلند",
    "United Arab Emirates" : "امارات متحده عربی",
    "Afghanistan" : "افغانستان",
    "Albania" : "آلبانی",
    "Armenia" : "ارمنستان",
    "Angola" : "آنگولا",
    "Argentina" : "آرژانتین",
    "Austria" : "استرالیا",
    "Australia" : "استرالیا",
    "Azerbaijan" : "آذربایجان",
    "Bosnia and Herzegowina" : "بوسنی و هرزگوین",
    "Bangladesh" : "بنگلادش",
    "Belgium" : "بلژیک",
    "Burkina Faso" : "بورکینافاسو",
    "Bulgaria" : "بلغارستان",
    "Burundi" : "بوروندی",
    "Benin" : "بنین",
    "Brunei" : "برونئی",
    "Bolivia" : "بولیوی",
    "Brazil" : "برزیل",
    "Bahamas" : "باهاما",
    "Bhutan" : "بوتان",
    "Botswana" : "بوتسوانا",
    "Belarus" : "بلاروس",
    "Belize" : "بلیز",
    "Canada" : "کانادا",
    "Democratic Republic of the Congo" : "جمهوری دموکراتیک کنگو",
    "Central African Republic" : "جمهوری آفریقای مرکزی",
    "Congo" : "کنگو",
    "Switzerland" : "سوئیس",
    "Cote d'Ivoire" : "ساحل عاج",
    "Chile" : "شیلی",
    "Cameroon" : "کامرون",
    "China" : "چین",
    "Colombia" : "کلومبیا",
    "Costa Rica" : "کاستاریکا",
    "Cuba" : "کوبا",
    "Cyprus" : "قبرس",
    "Czech" : "چک",
    "Germany" : "آلمان",
    "Djibouti" : "جیبوتی",
    "Denmark" : "دانمارک",
    "Dominican Republic" : "جمهوری دومینیکن",
    "Algeria" : "الجزایر",
    "Ecuador" : "اکوادور",
    "Estonia" : "استونی",
    "Egypt" : "مصر",
    "West Sahara" : "صحرای غربی",
    "Eritrea" : "اریتره",
    "Spain" : "اسپانیا",
    "Ethiopia" : "اتیوپی",
    "Finland" : "فنلاند",
    "Fiji" : "فیجی",
    "Falkland Islands" : "جزایر فالکلند",
    "France" : "فرانسه",
    "Gabon" : "گابن",
    "United Kingdom" : "انگلستان",
    "Georgia" : "جورجیا",
    "Ghana" : "غنا",
    "Greenland" : "گرینلند",
    "Gambia" : "گامبیا",
    "Guinea" : "گینه",
    "Equatorial Guinea" : "گینه استوایی",
    "Greece" : "یونان",
    "Guatemala" : "گواتمالا",
    "Guinea-Bissau" : "گینه بیسائو",
    "Guyana" : "گویان",
    "Honduras" : "هندوراس",
    "Croatia" : "کرواسی",
    "Haiti" : "هائیتی",
    "Hungary" : "مجارستان",
    "Indonesia" : "اندونزی",
    "Ireland" : "ایرلند",
    "Israel" : "اسرائیل",
    "India" : "هند",
    "Iraq" : "عراق",
    "Iran" : "ایران",
    "Iceland" : "ایسلند",
    "Italy" : "ایتالیا",
    "Jamaica" : "جامایکا",
    "Jordan" : "جردن",
    "Japan" : "ژاپن",
    "Kenya" : "کنیا",
    "Kyrgyzstan" : "قرقیزستان",
    "Cambodia" : "کمبوج",
    "North Korea" : "کره شمالی",
    "South Korea" : "کره جنوبی",
    "Kuwait" : "کویت",
    "Kazakhstan" : "قزاقستان",
    "Laos" : "لاوس",
    "Lebanon" : "لبنان",
    "Sri Lanka" : "سریلانکا",
    "Liberia" : "لیبریا",
    "Lesotho" : "لسوتو",
    "Lithuania" : "لیتوانی",
    "Luxembourg" : "لوکزامبورگ",
    "Latvia" : "لتونی",
    "Libya" : "لیبی",
    "Morocco" : "مراکش",
    "Moldova" : "مولداوی",
    "Montenegro" : "مونتنگرو",
    "Madagascar" : "ماداگاسکار",
    "Macedonia" : "مقدونیه",
    "Mali" : "مالی",
    "Myanmar" : "میانمار",
    "Mongolia" : "مغولستان",
    "Mauritania" : "موریتانی",
    "Malawi" : "مالاوی",
    "Mexico" : "مکزیک",
    "Malaysia" : "مالزی",
    "Mozambique" : "موزامبیک",
    "Namibia" : "ناميبيا",
    "New Caledonia" : "کالدونیای جدید",
    "Niger" : "نیجر",
    "Nigeria" : "نیجرا",
    "Nicaragua" : "نیجریه",
    "Netherlands" : "هلند",
    "Norway" : "نروژ",
    "Nepal" : "نپال",
    "New Zealand" : "نیوزلند",
    "Oman" : "عمان",
    "Panama" : "پاناما",
    "Peru" : "پرو",
    "Papua New Guinea" : "پاپوا گینه نو",
    "Philippines" : "فلیپین",
    "Pakistan" : "پاکستان",
    "Poland" : "لهستان",
    "Puerto Rico" : "پورتوریکو",
    "Portugal" : "پرتغال",
    "Paraguay" : "پاروگیه",
    "Qatar" : "قطر",
    "Romania" : "رومانی",
    "Serbia" : "صربستان",
    "Russia" : "روسیه",
    "Rwanda" : "رواندا",
    "Saudi Arabia" : "عربستان",
    "Solomon Islands" : "جزایر سلیمان",
    "Sudan" : "سودان",
    "Sweden" : "سوئد",
    "Singapore" : "سنگاپور",
    "Slovenia" : "اسلونی",
    "Slovakia" : "اسلواکی",
    "Sierra Leone" : "سیرا لئون",
    "Senegal" : "سنگال",
    "Somalia" : "سومالی",
    "Suriname" : "سوریه",
    "South Sudan" : "سومالی شمالی",
    "El Salvador" : "سلوادور",
    "Syria" : "سیریا",
    "Swaziland" : "سوازیلند",
    "Chad" : "چد",
    "Fr. S. Antarctic Lands" : "فر. S. قطب جنوب",
    "Togo" : "توگو",
    "Thailand" : "تایلند",
    "Tajikistan" : "تاجیکستان",
    "Timor-Leste" : "تیمور-لست",
    "Turkmenistan" : "ترکمنستان",
    "Tunisia" : "تونس",
    "Turkey" : "jv;di",
    "Trinidad and Tobago" : "ترینیداد و توباگو",
    "Taiwan" : "تایوان",
    "Tanzania" : "تانزانیا",
    "Ukraine" : "اوکراین",
    "Uganda" : "اوگاندا",
    "United States" : "انگلستان",
    "Uruguay" : "اوروگویه",
    "Uzbekistan" : "اوزبکستان",
    "Venezuela" : "ونزویلا",
    "Vietnam" : "ویتنام",
    "Vanuatu" : "وانتویو",
    "Yemen" : "یمن",
    "South Africa" : "آفریقا شمالی",
    "Zambia" : "زامبی",
    "Zimbabwe" : "زیمباوه",
    "Your Nextcloud account" : "شما نکست کلود حساب",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "داده  شما نشانگر شما چه کسی هستند و به راحتی می توانید از آنها سوء استفاده کنید. ما در نکست کلود معتقدیم که شما حق دارید تصمیم بگیرید که با داده های شما چه اتفاقی می افتد. نکست کلود از حقوق شما همانطور که در مانیفست داده اطلاعات کاربر تعریف شده است ، محافظت می کند!",
    "User Data Manifesto 2.0" : "مانیفست داده کاربر 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "تعیین حقوق اساسی برای افراد برای کنترل داده خود در عصر اینترنت",
    "Control" : "کنترل",
    "over user data access" : "از طریق دسترسی به داده  کاربر",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "داده  صریح و با اراده توسط کاربر بارگذاری می شود باید تحت کنترل نهایی کاربر باشد. کاربران باید بتوانند تصمیم بگیرند که چه کسی دسترسی مستقیم به داده های خود را داشته باشد و با چه مجوزها و مجوزهایی از این دسترسی استفاده شود.",
    "Knowledge" : "دانش",
    "of how the data is stored" : "نحوه ذخیره داده ها",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "هنگامی که داده  در یک ارائه دهنده سرویس خاص بارگذاری می شود ، کاربران باید درباره مکان ارائه دهنده خدمات خاص داده ها را ذخیره کنند ، چه مدت ، چه مدت ، در کدام حوزه قضایی ارائه دهنده سرویس خاص کار می کند و چه قوانینی اعمال می شود.",
    "Freedom" : "آزادی",
    "to choose a platform" : "برای انتخاب کردن یک سیستم عامل",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "کاربران همیشه باید بتوانند داده  خود را از هر زمان و بدون تجربه قفل شدن فروشنده از این سرویس استخراج کنند. استانداردهای باز برای قالب ها و پروتکل ها برای تضمین این امر ضروری است.",
    "Learn more ↗" : "بیشتر بدانید ↗",
    "Where is your data?" : "داده شما کجاست؟",
    "Who has access to your data?" : "چه کسی به داده شما دسترسی دارد؟",
    "Administrators" : "مدیران",
    "People you shared with" : "افرادی که با آنها به اشتراک گذاشتید",
    "Privacy policy" : "سیاست حفظ حریم خصوصی",
    "Read the privacy policy." : "خط مشی رازداری را بخوانید.",
    "Encryption" : "رمزگذاری"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-28.0.7.tar.bz2: nextcloud/apps/privacy/l10n/fa.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "حریم خصوصی",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "مرکز حفظ حریم خصوصی به شما نشان می دهد که داده های شما در کجا ذخیره شده است و چه کسی می تواند به آن دسترسی پیدا کند ، یا بخاطر اینکه با آنها به اشتراک گذاشته اید یا به دلیل اینکه آنها مدیر هستند",
    "Administrators" : "مدیران",
    "Remove external {propertyName} admin" : "Remove external {propertyName} admin",
    "Add external admin" : "اضافه کردن مدیر خارجی",
    "Cancel" : "منصرف شدن",
    "Name of external admin" : "Name of external admin",
    "Encryption" : "رمزگذاری",
    "Edit" : "ویرایش",
    "This server is using full-disk-encryption." : "این سرور از رمزگذاری کامل دیسک استفاده می کند.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration.",
    "Additionally, this server is protected with full-disk-encryption." : "Additionally, this server is protected with full-disk-encryption.",
    "This server is protected with full-disk-encryption." : "این سرور با رمزگذاری کامل دیسک محافظت می شود.",
    "Your files are not protected by encryption." : "پرونده های شما توسط رمزگذاری محافظت نمی شوند.",
    "Privacy policy" : "سیاست حفظ حریم خصوصی",
    "Who has access to your data?" : "چه کسی به داده شما دسترسی دارد؟",
    "Where is your data?" : "داده شما کجاست؟",
    "Your data is located in:" : "Your data is located in:",
    "Change data location" : "مکان داده را تغییر دهید",
    "Region" : "ناحیه",
    "Please select a region" : "Please select a region",
    "User Data Manifesto 2.0" : "مانیفست داده کاربر 2.0",
    "Control" : "کنترل",
    "over user data access" : "از طریق دسترسی به داده  کاربر",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "داده  صریح و با اراده توسط کاربر بارگذاری می شود باید تحت کنترل نهایی کاربر باشد. کاربران باید بتوانند تصمیم بگیرند که چه کسی دسترسی مستقیم به داده های خود را داشته باشد و با چه مجوزها و مجوزهایی از این دسترسی استفاده شود.",
    "Knowledge" : "دانش",
    "of how the data is stored" : "نحوه ذخیره داده ها",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "هنگامی که داده  در یک ارائه دهنده سرویس خاص بارگذاری می شود ، کاربران باید درباره مکان ارائه دهنده خدمات خاص داده ها را ذخیره کنند ، چه مدت ، چه مدت ، در کدام حوزه قضایی ارائه دهنده سرویس خاص کار می کند و چه قوانینی اعمال می شود.",
    "Freedom" : "آزادی",
    "to choose a platform" : "جهت انتخاب یک پلتفرم",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "کاربران همیشه باید بتوانند داده  خود را از هر زمان و بدون تجربه قفل شدن فروشنده از این سرویس استخراج کنند. استانداردهای باز برای قالب ها و پروتکل ها برای تضمین این امر ضروری است.",
    "Learn more ↗" : "بیشتر بدانید ↗",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "داده  شما نشانگر شما چه کسی هستند و به راحتی می توانید از آنها سوء استفاده کنید. ما در نکست کلود معتقدیم که شما حق دارید تصمیم بگیرید که با داده های شما چه اتفاقی می افتد. نکست کلود از حقوق شما همانطور که در مانیفست داده اطلاعات کاربر تعریف شده است ، محافظت می کند!",
    "Somaliland" : "سومالیلند",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "امارات متحده عربی",
    "Afghanistan" : "افغانستان",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "آلبانی",
    "Armenia" : "ارمنستان",
    "Angola" : "آنگولا",
    "Antarctica" : "Antarctica",
    "Argentina" : "آرژانتین",
    "American Samoa" : "American Samoa",
    "Austria" : "استرالیا",
    "Australia" : "استرالیا",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "آذربایجان",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "بنگلادش",
    "Belgium" : "بلژیک",
    "Burkina Faso" : "بورکینافاسو",
    "Bulgaria" : "بلغارستان",
    "Bahrain" : "Bahrain",
    "Burundi" : "بوروندی",
    "Benin" : "بنین",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei" : "برونئی",
    "Bolivia" : "بولیوی",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "برزیل",
    "Bahamas" : "باهاما",
    "Bhutan" : "بوتان",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "بوتسوانا",
    "Belarus" : "بلاروس",
    "Belize" : "بلیز",
    "Canada" : "کانادا",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Democratic Republic of the Congo" : "جمهوری دموکراتیک کنگو",
    "Central African Republic" : "جمهوری آفریقای مرکزی",
    "Congo" : "کنگو",
    "Switzerland" : "سوئیس",
    "Cote d'Ivoire" : "ساحل عاج",
    "Cook Islands" : "Cook Islands",
    "Chile" : "شیلی",
    "Cameroon" : "کامرون",
    "China" : "چین",
    "Colombia" : "کلومبیا",
    "Costa Rica" : "کاستاریکا",
    "Cuba" : "کوبا",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas Island",
    "Cyprus" : "قبرس",
    "Czech" : "چک",
    "Germany" : "آلمان",
    "Djibouti" : "جیبوتی",
    "Denmark" : "دانمارک",
    "Dominican Republic" : "جمهوری دومینیکن",
    "Algeria" : "الجزایر",
    "Ecuador" : "اکوادور",
    "Estonia" : "استونی",
    "Egypt" : "مصر",
    "West Sahara" : "صحرای غربی",
    "Eritrea" : "اریتره",
    "Spain" : "اسپانیا",
    "Ethiopia" : "اتیوپی",
    "Finland" : "فنلاند",
    "Fiji" : "فیجی",
    "Falkland Islands" : "جزایر فالکلند",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Faroe Islands",
    "France" : "فرانسه",
    "Gabon" : "گابن",
    "United Kingdom" : "انگلستان",
    "Grenada" : "Grenada",
    "Georgia" : "جورجیا",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "غنا",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "گرینلند",
    "Gambia" : "گامبیا",
    "Guinea" : "گینه",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "گینه استوایی",
    "Greece" : "یونان",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "گواتمالا",
    "Guam" : "Guam",
    "Guinea-Bissau" : "گینه بیسائو",
    "Guyana" : "گویان",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "هندوراس",
    "Croatia" : "کرواسی",
    "Haiti" : "هائیتی",
    "Hungary" : "مجارستان",
    "Indonesia" : "اندونزی",
    "Ireland" : "ایرلند",
    "Israel" : "اسرائیل",
    "Isle of Man" : "Isle of Man",
    "India" : "هند",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "عراق",
    "Iran" : "ایران",
    "Iceland" : "ایسلند",
    "Italy" : "ایتالیا",
    "Jamaica" : "جامایکا",
    "Jordan" : "جردن",
    "Japan" : "ژاپن",
    "Kenya" : "کنیا",
    "Kyrgyzstan" : "قرقیزستان",
    "Cambodia" : "کمبوج",
    "Kiribati" : "Kiribati",
    "Comores" : "Comores",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "North Korea" : "کره شمالی",
    "South Korea" : "کره جنوبی",
    "Kuwait" : "کویت",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "قزاقستان",
    "Laos" : "لاوس",
    "Lebanon" : "لبنان",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "سریلانکا",
    "Liberia" : "لیبریا",
    "Lesotho" : "لسوتو",
    "Lithuania" : "لیتوانی",
    "Luxembourg" : "لوکزامبورگ",
    "Latvia" : "لتونی",
    "Libya" : "لیبی",
    "Morocco" : "مراکش",
    "Monaco" : "Monaco",
    "Moldova" : "مولداوی",
    "Montenegro" : "مونتنگرو",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "ماداگاسکار",
    "Marshall Islands" : "Marshall Islands",
    "Macedonia" : "مقدونیه",
    "Mali" : "مالی",
    "Myanmar" : "میانمار",
    "Mongolia" : "مغولستان",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Mauritania" : "موریتانی",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "مالاوی",
    "Mexico" : "مکزیک",
    "Malaysia" : "مالزی",
    "Mozambique" : "موزامبیک",
    "Namibia" : "ناميبيا",
    "New Caledonia" : "کالدونیای جدید",
    "Niger" : "نیجر",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "نیجرا",
    "Nicaragua" : "نیجریه",
    "Netherlands" : "هلند",
    "Norway" : "نروژ",
    "Nepal" : "نپال",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "نیوزلند",
    "Oman" : "عمان",
    "Panama" : "پاناما",
    "Peru" : "پرو",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "پاپوا گینه نو",
    "Philippines" : "فلیپین",
    "Pakistan" : "پاکستان",
    "Poland" : "لهستان",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "پورتوریکو",
    "Palestine" : "Palestine",
    "Portugal" : "پرتغال",
    "Palau" : "Palau",
    "Paraguay" : "پاروگیه",
    "Qatar" : "قطر",
    "Réunion" : "Réunion",
    "Romania" : "رومانی",
    "Serbia" : "صربستان",
    "Russia" : "روسیه",
    "Rwanda" : "رواندا",
    "Saudi Arabia" : "عربستان",
    "Solomon Islands" : "جزایر سلیمان",
    "Seychelles" : "Seychelles",
    "Sudan" : "سودان",
    "Sweden" : "سوئد",
    "Singapore" : "سنگاپور",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "اسلونی",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "اسلواکی",
    "Sierra Leone" : "سیرا لئون",
    "San Marino" : "San Marino",
    "Senegal" : "سنگال",
    "Somalia" : "سومالی",
    "Suriname" : "سوریه",
    "South Sudan" : "سومالی شمالی",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "سلوادور",
    "Sint Maarten" : "Sint Maarten",
    "Syria" : "سیریا",
    "Swaziland" : "سوازیلند",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "چد",
    "Fr. S. Antarctic Lands" : "فر. S. قطب جنوب",
    "Togo" : "توگو",
    "Thailand" : "تایلند",
    "Tajikistan" : "تاجیکستان",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "تیمور-لست",
    "Turkmenistan" : "ترکمنستان",
    "Tunisia" : "تونس",
    "Tonga" : "تونگا",
    "Turkey" : "jv;di",
    "Trinidad and Tobago" : "ترینیداد و توباگو",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "تایوان",
    "Tanzania" : "تانزانیا",
    "Ukraine" : "اوکراین",
    "Uganda" : "اوگاندا",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States" : "انگلستان",
    "Uruguay" : "اوروگویه",
    "Uzbekistan" : "اوزبکستان",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela" : "ونزویلا",
    "Virgin Islands (British)" : "Virgin Islands (British)",
    "Virgin Islands (U.S.)" : "Virgin Islands (U.S.)",
    "Vietnam" : "ویتنام",
    "Vanuatu" : "وانتویو",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "یمن",
    "Mayotte" : "Mayotte",
    "South Africa" : "آفریقا شمالی",
    "Zambia" : "زامبی",
    "Zimbabwe" : "زیمباوه",
    "Adapt encryption" : "Adapt encryption",
    "The admin has not selected the location of the server yet." : "The admin has not selected the location of the server yet.",
    "You don't have any shares with individual users." : "شما با کاربران جداگانه اشتراکی ندارید.",
    "Your %s account" : "Your %s account",
    "Defining basic rights for people to control their own data in the internet age" : "تعیین حقوق اساسی برای افراد برای کنترل داده خود در عصر اینترنت",
    "People you shared with" : "افرادی که با آنها به اشتراک گذاشتید",
    "Read the privacy policy." : "خط مشی رازداری را بخوانید."
},
"nplurals=2; plural=(n > 1);");
